@@ -40,12 +40,12 @@ from ..responses import (
 )
 
 
-def accept_chat_request(self, chat_room_ids: List[int], access_token: str = None):
+def accept_chat_requests(self, chat_room_ids: List[int], access_token: str = None):
     self._check_authorization(access_token)
     response = self._make_request(
         "POST",
         endpoint=f"{Endpoints.CHAT_ROOMS_V1}/accept_chat_request",
-        payload={"chat_room_ids[]": chat_room_ids},
+        payload={"chat_room_ids": chat_room_ids},
         access_token=access_token,
     )
     self.logger.info("Accepted chat requests")
@@ -250,12 +250,19 @@ def get_messages(
 
 
 def get_request_chat_rooms(
-    self, from_timestamp: int = None, access_token: str = None
+    self, access_token: str = None, **params
 ) -> ChatRoomsResponse:
+    """
+
+    Parameters:
+    ----------
+
+        - number: int (optional)
+        - from_timestamp: int (optional)
+        - access_token: str (optional)
+
+    """
     self._check_authorization(access_token)
-    params = {}
-    if from_timestamp:
-        params["from_timestamp"] = from_timestamp
     return self._make_request(
         "GET",
         endpoint=f"{Endpoints.CHAT_ROOMS_V1}/request_list",
@@ -313,7 +320,7 @@ def invite_to_chat(
     response = self._make_request(
         "POST",
         endpoint=f"{Endpoints.CHAT_ROOMS_V2}/{chat_room_id}/invite",
-        payload={"with_user_ids[]": user_ids},
+        payload={"with_user_ids": user_ids},
         access_token=access_token,
     )
     self.logger.info("Invited users to the chatroom.")
@@ -427,6 +434,7 @@ def send_message(
     gif_image_id: int = None,
     attachment_file_name: str = None,
     sticker_pack_id: int = None,
+    sticker_id: int = None,
     video_file_name: str = None,
     access_token: str = None,
 ) -> MessageResponse:
@@ -435,7 +443,6 @@ def send_message(
         "POST",
         endpoint=f"{Endpoints.CHAT_ROOMS_V3}/{chat_room_id}/messages/new",
         payload={
-            "chat_room_id": chat_room_id,
             "message_type": message_type,
             "call_type": call_type,
             "text": text,
@@ -443,6 +450,7 @@ def send_message(
             "gif_image_id": gif_image_id,
             "attachment_file_name": attachment_file_name,
             "sticker_pack_id": sticker_pack_id,
+            "sticker_id": sticker_id,
             "video_file_name": video_file_name,
         },
         data_type=MessageResponse,
@@ -457,7 +465,7 @@ def unhide_chat(self, chat_room_ids: int, access_token: str = None):
     response = self._make_request(
         "DELETE",
         endpoint=f"{Endpoints.HIDDEN_V1}/chats",
-        params={"chat_room_ids[]": chat_room_ids},
+        params={"chat_room_ids": chat_room_ids},
         access_token=access_token,
     )
     self.logger.info("Unhid the chatrooms")
