@@ -279,7 +279,7 @@ def create_post(
             "in_reply_to": in_reply_to,
             "group_id": group_id,
             "post_type": post_type,
-            "mention_ids[]": mention_ids,
+            "mention_ids": mention_ids,
             "choices": choices,
             "shared_url": shared_url,
             "message_tags": message_tags,
@@ -366,7 +366,7 @@ def create_repost(
             "in_reply_to": in_reply_to,
             "group_id": group_id,
             "post_type": post_type,
-            "mention_ids[]": mention_ids,
+            "mention_ids": mention_ids,
             "choices": choices,
             "shared_url": shared_url,
             "message_tags": message_tags,
@@ -487,7 +487,7 @@ def create_thread_post(
             "in_reply_to": in_reply_to,
             "group_id": group_id,
             "post_type": post_type,
-            "mention_ids[]": mention_ids,
+            "mention_ids": mention_ids,
             "choices": choices,
             "shared_url": shared_url,
             "message_tags": message_tags,
