@@ -42,7 +42,9 @@ from .api.call import (
     set_call,
     set_user_role,
     start_call,
+    start_anonymous_call,
     stop_call,
+    stop__anonymous_call,
 )
 from .api.cassandra import (
     get_user_activities,
@@ -50,7 +52,7 @@ from .api.cassandra import (
     received_notification,
 )
 from .api.chat import (
-    accept_chat_request,
+    accept_chat_requests,
     check_unread_status,
     create_group_chat,
     create_private_chat,
@@ -237,7 +239,6 @@ from .api.user import (
     get_user_from_qr,
     get_user_without_leaving_footprint,
     get_users,
-    reduce_kenta_penalty,
     refresh_counter,
     register_user,
     remove_user_avatar,
@@ -339,8 +340,9 @@ class Client(API):
         - timeout: int - (optional)
         - err_lang: str - (optional)
         - base_path: str - (optional)
-        - loglevel_stream: int - (optional)
-        - host: str - (optional)
+        - save_session: bool - (optional)
+        - session_filename: str - (optional)
+        - loglevel: int - (optional)
 
     <https://github.com/qvco/yaylib>
 
@@ -348,7 +350,7 @@ class Client(API):
 
     ### Yay! (nanameue, Inc.) API Client
 
-    Copyright (c) 2023 Qvco, Konn
+    Copyright (c) 2023-present Qvco, Konn
 
     """
 
@@ -543,6 +545,16 @@ class Client(API):
         """
         return start_call(self, conference_id, call_sid, access_token)
 
+    def join_call_as_anonymous(
+        self, conference_id: int, agora_uid: str
+    ) -> ConferenceCall:
+        """
+
+        無名くんとして通話に参加します
+
+        """
+        return start_anonymous_call(self, conference_id, agora_uid)
+
     def leave_call(
         self, conference_id: int, call_sid: str = None, access_token: str = None
     ) -> dict:
@@ -553,6 +565,14 @@ class Client(API):
         """
         return stop_call(self, conference_id, call_sid, access_token)
 
+    def leave_call_as_anonymous(self, conference_id: int, agora_uid: str = None):
+        """
+
+        通話から退出します
+
+        """
+        return stop__anonymous_call(self, conference_id, agora_uid)
+
     # -CASSANDRA
 
     def get_activities(self, access_token: str = None, **params) -> ActivitiesResponse:
@@ -592,7 +612,7 @@ class Client(API):
 
     # -CHAT
 
-    def accept_chat_request(
+    def accept_chat_requests(
         self, chat_room_ids: List[int], access_token: str = None
     ) -> dict:
         """
@@ -605,7 +625,7 @@ class Client(API):
             - chat_room_ids: List[int] - (required)
 
         """
-        return accept_chat_request(self, chat_room_ids, access_token)
+        return accept_chat_requests(self, chat_room_ids, access_token)
 
     def check_unread_status(
         self, from_time: int, access_token: str = None
@@ -776,15 +796,22 @@ class Client(API):
         """
         return get_messages(self, chat_room_id, access_token, **params)
 
-    def get_request_chat_rooms(
-        self, from_timestamp: int = None, access_token: str = None
+    def get_chat_requests(
+        self, access_token: str = None, **params
     ) -> ChatRoomsResponse:
         """
 
         チャットリクエストを取得します
 
+        Parameters:
+        ----------
+
+            - number: int (optional)
+            - from_timestamp: int (optional)
+            - access_token: str (optional)
+
         """
-        return get_request_chat_rooms(self, from_timestamp, access_token)
+        return get_request_chat_rooms(self, access_token, **params)
 
     def get_chat_room(self, chat_room_id: int, access_token: str = None) -> ChatRoom:
         """
@@ -916,6 +943,7 @@ class Client(API):
         gif_image_id: int = None,
         attachment_file_name: str = None,
         sticker_pack_id: int = None,
+        sticker_id: int = None,
         video_file_name: str = None,
         access_token: str = None,
     ) -> MessageResponse:
@@ -934,6 +962,7 @@ class Client(API):
             gif_image_id,
             attachment_file_name,
             sticker_pack_id,
+            sticker_id,
             video_file_name,
             access_token,
         )
@@ -2915,14 +2944,6 @@ class Client(API):
         """
         return get_users(self, user_ids, access_token)
 
-    def reduce_kenta_penalty(self, user_id: int, access_token: str = None) -> dict:
-        """
-
-        ペナルティーを緩和します
-
-        """
-        return reduce_kenta_penalty(self, user_id, access_token)
-
     def refresh_counter(self, counter: str, access_token: str = None) -> dict:
         """
 
