@@ -254,7 +254,7 @@ class TotalChatRequestResponse:
 
     def __init__(self, data):
         self.data = data
-        self.chat = data.get("total")
+        self.total = data.get("total")
 
     def __repr__(self):
         return f"TotalChatRequestResponse(data={self.data})"
@@ -365,11 +365,14 @@ class EmailGrantTokenResponse:
 
 
 class EmailVerificationPresignedUrlResponse:
-    __slots__ = ("data", "url")
+    __slots__ = ("data", "url", "presigned_url", "expires_at", "method_type")
 
     def __init__(self, data):
         self.data = data
         self.url = data.get("url")
+        self.presigned_url = data.get("presigned_url")
+        self.expires_at = data.get("expires_at")
+        self.method_type = data.get("method_type")
 
     def __repr__(self):
         return f"EmailVerificationPresignedUrlResponse(data={self.data})"
@@ -573,7 +576,7 @@ class GroupResponse:
 
         self.group = data.get("group")
         if self.group is not None:
-            self.group = Setting(self.group)
+            self.group = Group(self.group)
 
     def __repr__(self):
         return f"GroupResponse(data={self.data})"
@@ -1187,6 +1190,36 @@ class UserTimestampResponse:
         return f"UserTimestampResponse(data={self.data})"
 
 
+class ChannelResponse:
+    __slots__ = ("data", "identifier", "message", "type", "sid")
+
+    def __init__(self, data):
+        self.data = data
+        self.identifier = data.get("identifier")
+
+        self.message = data.get("message")
+        if self.message is not None and isinstance(self.message, dict):
+            self.message = WebSocketMessageResponse(self.message)
+
+        self.type = data.get("type")
+        self.sid = data.get("sid")
+
+    def __repr__(self):
+        return f"ChannelResponse(data={self.data})"
+
+
+class WebSocketMessageResponse:
+    __slots__ = ("response", "data", "event")
+
+    def __init__(self, data):
+        self.response = data
+        self.data = data.get("data")
+        self.event = data.get("event")
+
+    def __repr__(self):
+        return f"WebSocketMessageResponse(response={self.response})"
+
+
 class WebSocketTokenResponse:
     __slots__ = ("data", "token")
 
