@@ -52,10 +52,12 @@ def console_print(*args):
     print("\n")
 
 
-def generate_uuid() -> tuple:
+def generate_uuid(uuid_type: bool = True) -> tuple:
     generated_uuid = str(uuid.uuid4())
-    url_uuid = generated_uuid.replace("-", "")
-    return generated_uuid, url_uuid
+    if uuid_type:
+        return generated_uuid
+    else:
+        return generated_uuid.replace("-", "")
 
 
 def parse_datetime(timestamp: int) -> str:
@@ -64,74 +66,76 @@ def parse_datetime(timestamp: int) -> str:
     return timestamp
 
 
-def encrypt(fernet, credentials: dict):
-    credentials.update(
+def encrypt(fernet, session: dict):
+    session.update(
         {
             "access_token": fernet.encrypt(
-                credentials.get("access_token").encode()
+                session.get("access_token").encode()
             ).decode(),
             "refresh_token": fernet.encrypt(
-                credentials.get("refresh_token").encode()
+                session.get("refresh_token").encode()
             ).decode(),
         }
     )
-    return credentials
+    return session
 
 
-def decrypt(fernet, credentials: dict):
-    credentials.update(
+def decrypt(fernet, session: dict):
+    session.update(
         {
-            "access_token": fernet.decrypt(credentials.get("access_token")).decode(),
-            "refresh_token": fernet.decrypt(credentials.get("refresh_token")).decode(),
+            "access_token": fernet.decrypt(session.get("access_token")).decode(),
+            "refresh_token": fernet.decrypt(session.get("refresh_token")).decode(),
         }
     )
-    return credentials
+    return session
 
 
 def save_session(
     base_path: str,
+    session_filename: str,
     fernet,
     access_token: str,
     refresh_token: str,
     user_id: int,
     email: str = None,
 ):
-    credentials = load_session(base_path=base_path)
-    updated_credentials = {
+    session = load_session(base_path=base_path, session_filename=session_filename)
+    updated_session = {
         "access_token": access_token,
         "refresh_token": refresh_token,
         "user_id": user_id,
         "email": email,
     }
     if email is None:
-        updated_credentials["email"] = credentials.get("email")
+        updated_session["email"] = session.get("email")
 
-    updated_credentials = encrypt(fernet, updated_credentials)
+    updated_session = encrypt(fernet, updated_session)
 
-    with open(base_path + "credentials.json", "w") as f:
-        json.dump(updated_credentials, f)
+    with open(base_path + session_filename + ".json", "w") as f:
+        json.dump(updated_session, f, indent=4)
 
 
-def load_session(base_path: str, fernet=None, check_email: str = None):
-    if not os.path.exists(base_path + "credentials.json"):
+def load_session(
+    base_path: str, session_filename: str, fernet=None, check_email: str = None
+):
+    if not os.path.exists(base_path + session_filename + ".json"):
         return None
 
-    with open(base_path + "credentials.json", "r") as f:
-        credentials = json.load(f)
+    with open(base_path + session_filename + ".json", "r") as f:
+        session = json.load(f)
 
     result = all(
-        key in credentials
-        for key in ("access_token", "refresh_token", "user_id", "email")
+        key in session for key in ("access_token", "refresh_token", "user_id", "email")
     )
-    credentials = None if result is False else credentials
+    session = None if result is False else session
 
-    if check_email is not None and credentials is not None:
-        credentials = None if check_email != credentials["email"] else credentials
+    if check_email is not None and session is not None:
+        session = None if check_email != session["email"] else session
 
-    if fernet is not None and credentials is not None:
-        credentials = decrypt(fernet, credentials)
+    if fernet is not None and session is not None:
+        session = decrypt(fernet, session)
 
-    return credentials
+    return session
 
 
 def signed_info_calculating(uuid: str, timestamp: int, shared_key: bool = False) -> str:
